# Copyright (c) 2003-2004 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

__author__ = "Jean-Marc Orliaguet <jmo@ita.chalmers.se>"

"""
  Base Palette
"""

from Globals import InitializeClass, DTMLFile
from AccessControl import ClassSecurityInfo
from OFS.PropertyManager import PropertyManager
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.PortalContent import PortalContent

from CPSSkinsPermissions import ManageThemes
from cpsskins_utils import callAction

def addBasePalette(dispatcher, id, REQUEST=None):
    """Add a Base Palette."""
    ob = BasePalette(id)
    container = dispatcher.Destination()
    container._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Base Palette',
     'description': ('A Base Palette is the most basic palette.'),
     'meta_type': 'Base Palette',
     'icon': 'palette_icon.gif',
     'product': 'CPSSkins',
     'factory': 'addBasePalette',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'actions': (
         {'id': 'edit',
          'name': 'Edit',
          'action': 'cpsskins_edit_form',
          'permissions': (ManageThemes,)
         },
         {'id': 'delete',
          'name': 'Delete',
          'action': 'cpsskins_object_delete',
          'visible': 0,
          'permissions': (ManageThemes,)
         },
         {'id': 'ispalette',
          'name': 'ispalette',
          'action': 'ispalette',
          'visible': 0,
          'permissions': ()},
     ),
    },
)

class BasePalette(PortalContent, PropertyManager):
    """
    Base class for palettes
    """

    meta_type = None
    portal_type = None
    ispalette = 1

    manage_options = ( PropertyManager.manage_options      # Properties
                    + (
                       {'label': 'Preview',
                        'action': 'manage_palettePreview'}, 
                      )
                     )

    security = ClassSecurityInfo()
    security.declareProtected(View, 'manage_palettePreview')
    manage_palettePreview = DTMLFile('zmi/manage_palettePreview', globals())

    _actions = factory_type_information[0]['actions']

    _properties = (
       {'id': 'title', 
        'type': 'string', 
        'mode': 'w', 
        'label': 'Title'},
        )

    def __init__(self, id, 
                       title= 'Palette', 
                       **kw):
        self.id = id
        self.title = title

    security.declareProtected(View,'isPortalPalette')
    def isPortalPalette(self):
        """ is palette """
           
        return 1

    security.declareProtected(View,'isPortalContent')
    def isPortalContent(self):
        """ is portal content """
                  
        return 0  

    security.declarePublic('getIconRelative')
    def getIconRelative(self):
        """
        Gets the Icon path, relative to the portal.
        This is needed to catalog correctly in the presence of VHM.
        """
        return self.getIcon(1)

    security.declareProtected(ManageThemes, 'edit_form')
    def edit_form(self, **kw):
        """
        Call the edit action.
        """
        return callAction(self, 'edit', **kw)

    security.declareProtected(ManageThemes, 'edit')
    def edit(self, **kw):
        """
        Default edit method, changes the properties.
        """
        self.manage_changeProperties(**kw)


    security.declareProtected(View, 'can_delete')
    def can_delete(self):
        """
        Can the palette be deleted ?
        """

        return 1


    security.declarePublic('getInfo')
    def getInfo(self):
        """ Return information about the palette """
        infoblock = {}
        actions_list = ['delete', ]

        ti = self.getTypeInfo()
        for actionid in actions_list:  
            actioninfo = {}
            if actionid == 'delete':
                actioninfo['can_delete'] = self.can_delete()
            try:
                action = ti.getActionById(actionid)
                actioninfo['url']  = self.absolute_url() + '/' + \
                                    self.restrictedTraverse(action).getId()
            except:
                continue 

            infoblock[actionid] = actioninfo
        return infoblock 

    security.declareProtected(View, 'preview')
    def preview(self, *args, **kw):
        """
        Renders a preview of the palette
        """

        return callAction(self, 'preview', **kw)

InitializeClass(BasePalette)
