import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

import unittest
import CPSSkinsTestCase
from Testing import ZopeTestCase

HTTP_OK = 200
HTTP_UNAUTHORIZED = 401
HTTP_REDIRECT = 302

class TestFunctional(ZopeTestCase.Functional, CPSSkinsTestCase.CPSSkinsTestCase):
    def afterSetUp(self):
        tmtool = self.portal.portal_themes
        if 'PortalTheme' in tmtool.objectIds():
           tmtool.manage_delObjects(['PortalTheme'])
        self.theme_container = tmtool.addPortalTheme()
        self.basic_auth = '%s:secret' % self.login_id
        self.theme_url = self.theme_container.absolute_url(1)


# Testing as 'Manager'
class TestFunctionalAsManager(TestFunctional):
    login_id = 'cpsskins_root'

    def test_1(self):
        for mode in ['layout', 'mixed', 'wysiwyg']:
            test_url = '/%s/edit_form?edit_mode=%s' % (self.theme_url, mode)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2a(self):
        test_url = '/%s/cpsskins_edit_styles' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2b(self):
        test_url = '/%s/cpsskins_edit_images' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2c(self):
        test_url = '/%s/cpsskins_edit_palettes' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2d(self):
        test_url = '/%s/cpsskins_cache_manager' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2e(self):
        test_url = '/%s/manage_main' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_3(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = pageblock.getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), int(0), int(0), dest_pageblock)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_4(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = theme_container.addPageBlock().getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), int(0), int(0), dest_pageblock)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_REDIRECT)

    def test_5(self):
        theme_container = self.theme_container
        test_url = '/%s/cpsskins_pageblock_add?pageblock_xpos=%s' \
            % (theme_container.absolute_url(1), int(0))
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_REDIRECT)

    def test_6(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_add?xpos=%s&ypos=%s&type_name=%s' \
            % (pageblock.absolute_url(1), int(0), int(0), 'Text Box Templet')
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_REDIRECT)

    def test_8(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_movedown' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_9(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveleft' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_10(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveup' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_11(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveright' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_12(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        test_url = '/%s/cpsskins_templet_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])


# Testing as 'Member'
class TestFunctionalAsMember(TestFunctional):
    login_id = 'cpsskins_user'

    def test_1(self):
        for mode in ['layout', 'mixed', 'wysiwyg']:
            test_url = '/%s/edit_form?edit_mode=%s' % (self.theme_url, mode)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_2a(self):
        test_url = '/%s/cpsskins_edit_styles' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_2b(self):
        test_url = '/%s/cpsskins_edit_images' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_2c(self):
        test_url = '/%s/cpsskins_edit_palettes' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_2d(self):
        test_url = '/%s/cpsskins_cache_manager' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_2e(self):
        test_url = '/%s/manage_main' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_3(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = pageblock.getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), int(0), int(0), dest_pageblock)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_4(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = theme_container.addPageBlock().getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), int(0), int(0), dest_pageblock)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_5(self):
        theme_container = self.theme_container
        test_url = '/%s/cpsskins_pageblock_add?pageblock_xpos=%s' \
            % (theme_container.absolute_url(1), int(0))
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_6(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_add?xpos=%s&ypos=%s&type_name=%s' \
            % (pageblock.absolute_url(1), int(0), int(0), 'Text Box Templet')
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_8(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_movedown' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_9(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveleft' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_10(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveup' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_11(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveright' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_12(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        test_url = '/%s/cpsskins_templet_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)


# Testing as 'Theme Manager'
class TestFunctionalAsThemeManager(TestFunctional):
    login_id = 'cpsskins_theme_manager'

    def test_1(self):
        for mode in ['layout', 'mixed', 'wysiwyg']:
            test_url = '/%s/edit_form?edit_mode=%s' % (self.theme_url, mode)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2a(self):
        test_url = '/%s/cpsskins_edit_styles' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2b(self):
        test_url = '/%s/cpsskins_edit_images' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2c(self):
        test_url = '/%s/cpsskins_edit_palettes' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_2d(self):
        test_url = '/%s/cpsskins_cache_manager' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_2e(self):
        test_url = '/%s/manage_main' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_3(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = pageblock.getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), int(0), int(0), dest_pageblock)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_4(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        dest_pageblock = theme_container.addPageBlock().getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), int(0), int(0), dest_pageblock)
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_REDIRECT)

    def test_5(self):
        theme_container = self.theme_container
        test_url = '/%s/cpsskins_pageblock_add?pageblock_xpos=%s' \
            % (theme_container.absolute_url(1), int(0))
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_REDIRECT)

    def test_6(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_add?xpos=%s&ypos=%s&type_name=%s' \
            % (pageblock.absolute_url(1), int(0), int(0), 'Text Box Templet')
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_REDIRECT)

    def test_8(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_movedown' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_9(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveleft' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_10(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveup' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_11(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        theme_container.addPageBlock()
        test_url = '/%s/cpsskins_templet_moveright' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

    def test_12(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        test_url = '/%s/cpsskins_templet_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() in [HTTP_REDIRECT, HTTP_OK])

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestFunctionalAsManager))
    suite.addTest(unittest.makeSuite(TestFunctionalAsMember))
    suite.addTest(unittest.makeSuite(TestFunctionalAsThemeManager))
    return suite

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)

